@@ -23,6 +23,7 @@ impl Icons {
     const DOCUMENT: char        = '\u{f1c2}';  // 
     const DOWNLOAD: char        = '\u{f01da}'; // 󰇚
     const EMACS: char           = '\u{e632}';  // 
+    const ESLINT: char          = '\u{e655}';  // 
     const FILE: char            = '\u{f15b}';  // 
     const FILE_OUTLINE: char    = '\u{f016}';  // 
     const FOLDER: char          = '\u{e5ff}';  // 
@@ -49,9 +50,11 @@ impl Icons {
     const LANG_C: char          = '\u{e61e}';  // 
     const LANG_CPP: char        = '\u{e61d}';  // 
     const LANG_CSHARP: char     = '\u{f031b}'; // 󰌛
+    const LANG_D: char          = '\u{e7af}';  // 
     const LANG_ELIXIR: char     = '\u{e62d}';  // 
     const LANG_FSHARP: char     = '\u{e7a7}';  // 
     const LANG_GO: char         = '\u{e65e}';  // 
+    const LANG_GROOVY: char     = '\u{e775}';  // 
     const LANG_HASKELL: char    = '\u{e777}';  // 
     const LANG_JAVA: char       = '\u{e256}';  // 
     const LANG_JAVASCRIPT: char = '\u{e74e}';  // 
@@ -89,8 +92,8 @@ impl Icons {
     const REACT: char           = '\u{e7ba}';  // 
     const README: char          = '\u{f00ba}'; // 󰂺
     const SHEET: char           = '\u{f1c3}';  // 
-    const SHELL_CMD: char       = '\u{f489}';  // 
     const SHELL: char           = '\u{f1183}'; // 󱆃
+    const SHELL_CMD: char       = '\u{f489}';  // 
     const SHIELD_CHECK: char    = '\u{f0565}'; // 󰕥
     const SHIELD_KEY: char      = '\u{f0bc4}'; // 󰯄
     const SHIELD_LOCK: char     = '\u{f099d}'; // 󰦝
@@ -119,6 +122,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     ".npm"                => Icons::FOLDER_NPM,     // 
     ".ssh"                => Icons::FOLDER_KEY,     // 󰢬
     ".Trash"              => '\u{f1f8}',            // 
+    "config"              => Icons::FOLDER_CONFIG,  // 
     "Contacts"            => '\u{f024c}',           // 󰉌
     "cron.d"              => Icons::FOLDER_CONFIG,  // 
     "cron.daily"          => Icons::FOLDER_CONFIG,  // 
@@ -127,7 +131,6 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "cron.weekly"         => Icons::FOLDER_CONFIG,  // 
     "Desktop"             => '\u{f108}',            // 
     "Downloads"           => '\u{f024d}',           // 󰉍
-    "config"              => Icons::FOLDER_CONFIG,  // 
     "etc"                 => Icons::FOLDER_CONFIG,  // 
     "Favorites"           => '\u{f069d}',           // 󰚝
     "hidden"              => Icons::FOLDER_HIDDEN,  // 󱞞
@@ -160,6 +163,11 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".cshrc"              => Icons::SHELL,          // 󱆃
     ".DS_Store"           => Icons::OS_APPLE,       // 
     ".emacs"              => Icons::EMACS,          // 
+    ".eslintrc.cjs"       => Icons::ESLINT,         // 
+    ".eslintrc.js"        => Icons::ESLINT,         // 
+    ".eslintrc.json"      => Icons::ESLINT,         // 
+    ".eslintrc.yaml"      => Icons::ESLINT,         // 
+    ".eslintrc.yml"       => Icons::ESLINT,         // 
     ".gitattributes"      => Icons::GIT,            // 
     ".gitconfig"          => Icons::GIT,            // 
     ".gitignore"          => Icons::GIT,            // 
@@ -174,6 +182,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".kshrc"              => Icons::SHELL,          // 󱆃
     ".login"              => Icons::SHELL,          // 󱆃
     ".logout"             => Icons::SHELL,          // 󱆃
+    ".mailmap"            => Icons::GIT,            // 
     ".node_repl_history"  => Icons::NODEJS,         // 
     ".npmignore"          => Icons::NPM,            // 
     ".npmrc"              => Icons::NPM,            // 
@@ -213,6 +222,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "configure.ac"        => Icons::CONFIG,         // 
     "configure.in"        => Icons::CONFIG,         // 
     "constraints.txt"     => Icons::LANG_PYTHON,    // 
+    "COPYING"             => Icons::LICENSE,        // 
+    "COPYRIGHT"           => Icons::LICENSE,        // 
     "crontab"             => Icons::CONFIG,         // 
     "crypttab"            => Icons::CONFIG,         // 
     "csh.cshrc"           => Icons::SHELL,          // 󱆃
@@ -255,6 +266,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "LICENCE.md"          => Icons::LICENSE,        // 
     "LICENCE.txt"         => Icons::LICENSE,        // 
     "LICENSE"             => Icons::LICENSE,        // 
+    "LICENSE-APACHE"      => Icons::LICENSE,        // 
+    "LICENSE-MIT"         => Icons::LICENSE,        // 
     "LICENSE.md"          => Icons::LICENSE,        // 
     "LICENSE.txt"         => Icons::LICENSE,        // 
     "localized"           => Icons::OS_APPLE,       // 
@@ -271,8 +284,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "package-lock.json"   => Icons::NPM,            // 
     "package.json"        => Icons::NPM,            // 
     "passwd"              => Icons::LOCK,           // 
-    "PKGBUILD"            => '\u{f303}',            // 
     "php.ini"             => Icons::LANG_PHP,       // 
+    "PKGBUILD"            => '\u{f303}',            // 
     "pom.xml"             => '\u{e674}',            // 
     "Procfile"            => '\u{e77b}',            // 
     "profile"             => Icons::SHELL,          // 󱆃
@@ -308,12 +321,16 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "acc"            => Icons::AUDIO,            // 
     "acf"            => '\u{f1b6}',              // 
     "ai"             => '\u{e7b4}',              // 
+    "aif"            => Icons::AUDIO,            // 
+    "aifc"           => Icons::AUDIO,            // 
+    "aiff"           => Icons::AUDIO,            // 
     "alac"           => Icons::AUDIO,            // 
     "android"        => Icons::OS_ANDROID,       // 
     "ape"            => Icons::AUDIO,            // 
     "apk"            => Icons::OS_ANDROID,       // 
     "apple"          => Icons::OS_APPLE,         // 
     "ar"             => Icons::COMPRESSED,       // 
+    "arj"            => Icons::COMPRESSED,       // 
     "arw"            => Icons::IMAGE,            // 
     "asc"            => Icons::SHIELD_LOCK,      // 󰦝
     "asm"            => Icons::LANG_ASSEMBLY,    // 
@@ -357,7 +374,9 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "cp"             => Icons::LANG_CPP,         // 
     "cpio"           => Icons::COMPRESSED,       // 
     "cpp"            => Icons::LANG_CPP,         // 
+    "cr"             => '\u{e62f}',              // 
     "cr2"            => Icons::IMAGE,            // 
+    "crdownload"     => Icons::DOWNLOAD,         // 󰇚
     "crt"            => Icons::GIST_SECRET,      // 
     "cs"             => Icons::LANG_CSHARP,      // 󰌛
     "csh"            => Icons::SHELL_CMD,        // 
@@ -370,11 +389,12 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "cu"             => '\u{e64b}',              // 
     "cue"            => Icons::PLAYLIST,         // 󰲹
     "cxx"            => Icons::LANG_CPP,         // 
-    "d"              => '\u{e7af}',              // 
+    "d"              => Icons::LANG_D,           // 
     "dart"           => '\u{e798}',              // 
     "db"             => Icons::DATABASE,         // 
     "deb"            => '\u{e77d}',              // 
     "desktop"        => '\u{ebd1}',              // 
+    "di"             => Icons::LANG_D,           // 
     "diff"           => Icons::DIFF,             // 
     "djv"            => Icons::DOCUMENT,         // 
     "djvu"           => Icons::DOCUMENT,         // 
@@ -409,6 +429,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "fish"           => Icons::SHELL_CMD,        // 
     "flac"           => Icons::AUDIO,            // 
     "flv"            => Icons::VIDEO,            // 
+    "fnt"            => Icons::FONT,             // 
+    "fon"            => Icons::FONT,             // 
     "font"           => Icons::FONT,             // 
     "fs"             => Icons::LANG_FSHARP,      // 
     "fsi"            => Icons::LANG_FSHARP,      // 
@@ -423,13 +445,17 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "go"             => Icons::LANG_GO,          // 
     "gpg"            => Icons::SHIELD_LOCK,      // 󰦝
     "gradle"         => Icons::GRADLE,           // 
-    "groovy"         => '\u{e775}',              // 
+    "groovy"         => Icons::LANG_GROOVY,      // 
     "gsheet"         => Icons::SHEET,            // 
     "gslides"        => Icons::SLIDE,            // 
     "guardfile"      => Icons::LANG_RUBY,        // 
     "gv"             => '\u{f1049}',             // 󱁉
+    "gvy"            => Icons::LANG_GROOVY,      // 
     "gz"             => Icons::COMPRESSED,       // 
     "h"              => Icons::LANG_C,           // 
+    "h++"            => Icons::LANG_CPP,         // 
+    "h264"           => Icons::VIDEO,            // 
+    "haml"           => '\u{e664}',              // 
     "hbs"            => Icons::MUSTACHE,         // 
     "heic"           => Icons::IMAGE,            // 
     "heics"          => Icons::VIDEO,            // 
@@ -447,6 +473,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "image"          => Icons::DISK_IMAGE,       // 
     "img"            => Icons::DISK_IMAGE,       // 
     "iml"            => Icons::INTELLIJ,         // 
+    "inl"            => Icons::LANG_C,           // 
     "ini"            => Icons::CONFIG,           // 
     "ipynb"          => '\u{e678}',              // 
     "iso"            => Icons::DISK_IMAGE,       // 
@@ -482,12 +509,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ldb"            => Icons::DATABASE,         // 
     "less"           => '\u{e758}',              // 
     "lhs"            => Icons::LANG_HASKELL,     // 
+    "lib"            => Icons::LIBRARY,          // 
     "license"        => Icons::LICENSE,          // 
     "lisp"           => '\u{f0172}',             // 󰅲
-    "lib"            => Icons::LIBRARY,          // 
     "localized"      => Icons::OS_APPLE,         // 
     "lock"           => Icons::LOCK,             // 
     "log"            => '\u{f18d}',              // 
+    "ltx"            => Icons::LANG_TEX,         // 
     "lua"            => '\u{e620}',              // 
     "lz"             => Icons::COMPRESSED,       // 
     "lz4"            => Icons::COMPRESSED,       // 
@@ -506,6 +534,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "md"             => Icons::MARKDOWN,         // 
     "md5"            => Icons::SHIELD_CHECK,     // 󰕥
     "mdb"            => Icons::DATABASE,         // 
+    "mid"            => '\u{f08f2}',             // 󰣲
     "mjs"            => Icons::LANG_JAVASCRIPT,  // 
     "mk"             => Icons::MAKE,             // 
     "mka"            => Icons::AUDIO,            // 
@@ -544,9 +573,10 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "out"            => '\u{eb2c}',              // 
     "p12"            => Icons::KEY,              // 
     "par"            => Icons::COMPRESSED,       // 
-    "part"           => '\u{f43a}',              // 
+    "part"           => Icons::DOWNLOAD,         // 󰇚
     "patch"          => Icons::DIFF,             // 
     "pbm"            => Icons::IMAGE,            // 
+    "pcm"            => Icons::AUDIO,            // 
     "pdf"            => '\u{f1c1}',              // 
     "pem"            => Icons::KEY,              // 
     "pfx"            => Icons::KEY,              // 
@@ -563,6 +593,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "pod"            => Icons::LANG_PERL,        // 
     "pp"             => '\u{e631}',              // 
     "ppm"            => Icons::IMAGE,            // 
+    "pps"            => Icons::SLIDE,            // 
+    "ppsx"           => Icons::SLIDE,            // 
     "ppt"            => Icons::SLIDE,            // 
     "pptx"           => Icons::SLIDE,            // 
     "properties"     => Icons::JSON,             // 
@@ -570,9 +602,10 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ps1"            => Icons::POWERSHELL,       // 
     "psd"            => '\u{e7b8}',              // 
     "psd1"           => Icons::POWERSHELL,       // 
-    "psm1"           => Icons::POWERSHELL,       // 
     "psf"            => Icons::FONT,             // 
+    "psm1"           => Icons::POWERSHELL,       // 
     "pub"            => Icons::PUBLIC_KEY,       // 󰷖
+    "purs"           => '\u{e630}',              // 
     "pxm"            => Icons::IMAGE,            // 
     "py"             => Icons::LANG_PYTHON,      // 
     "pyc"            => Icons::LANG_PYTHON,      // 
@@ -606,6 +639,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "rubydoc"        => Icons::LANG_RUBYRAILS,   // 
     "s"              => Icons::LANG_ASSEMBLY,    // 
     "sass"           => Icons::LANG_SASS,        // 
+    "sbt"            => Icons::SUBTITLE,         // 󰨖
     "scala"          => '\u{e737}',              // 
     "scss"           => Icons::LANG_SASS,        // 
     "service"        => '\u{eba2}',              // 
@@ -616,6 +650,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sha384"         => Icons::SHIELD_CHECK,     // 󰕥
     "sha512"         => Icons::SHIELD_CHECK,     // 󰕥
     "shell"          => Icons::SHELL_CMD,        // 
+    "shtml"          => Icons::HTML5,            // 
     "sig"            => Icons::SIGNED_FILE,      // 󱧃
     "signature"      => Icons::SIGNED_FILE,      // 󱧃
     "slim"           => Icons::LANG_RUBYRAILS,   // 
@@ -624,6 +659,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sql"            => Icons::DATABASE,         // 
     "sqlite3"        => '\u{e7c4}',              // 
     "srt"            => Icons::SUBTITLE,         // 󰨖
+    "ssa"            => Icons::SUBTITLE,         // 󰨖
     "stl"            => Icons::IMAGE,            // 
     "sty"            => Icons::LANG_TEX,         // 
     "styl"           => Icons::LANG_STYLUS,      // 
@@ -656,6 +692,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "tif"            => Icons::IMAGE,            // 
     "tiff"           => Icons::IMAGE,            // 
     "tlz"            => Icons::COMPRESSED,       // 
+    "tml"            => Icons::CONFIG,           // 
     "toml"           => Icons::CONFIG,           // 
     "torrent"        => '\u{e275}',              // 
     "ts"             => Icons::LANG_TYPESCRIPT,  // 
@@ -670,6 +707,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "tzo"            => Icons::COMPRESSED,       // 
     "unity"          => Icons::UNITY,            // 
     "unity3d"        => Icons::UNITY,            // 
+    "v"              => '\u{e6ac}',              // 
     "vdi"            => Icons::DISK_IMAGE,       // 
     "vhd"            => Icons::DISK_IMAGE,       // 
     "video"          => Icons::VIDEO,            // 
@@ -680,6 +718,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "war"            => Icons::LANG_JAVA,        // 
     "wav"            => Icons::AUDIO,            // 
     "webm"           => Icons::VIDEO,            // 
+    "webmanifest"    => Icons::JSON,             // 
     "webp"           => Icons::IMAGE,            // 
     "whl"            => Icons::LANG_PYTHON,      // 
     "windows"        => Icons::OS_WINDOWS,       // 
@@ -687,8 +726,10 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "wmv"            => Icons::VIDEO,            // 
     "woff"           => Icons::FONT,             // 
     "woff2"          => Icons::FONT,             // 
+    "wv"             => Icons::AUDIO,            // 
     "xcf"            => Icons::IMAGE,            // 
     "xhtml"          => Icons::HTML5,            // 
+    "xlr"            => Icons::SHEET,            // 
     "xls"            => Icons::SHEET,            // 
     "xlsm"           => Icons::SHEET,            // 
     "xlsx"           => Icons::SHEET,            // 
@@ -699,7 +740,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "yaml"           => Icons::YAML,             // 
     "yml"            => Icons::YAML,             // 
     "z"              => Icons::COMPRESSED,       // 
-    "zig"            => '\u{21af}',              // ↯
+    "zig"            => '\u{e6a9}',              // 
     "zip"            => Icons::COMPRESSED,       // 
     "zsh"            => Icons::SHELL_CMD,        // 
     "zsh-theme"      => Icons::SHELL,            // 󱆃
