@@ -20,3 +20,9 @@ fn cli_windows_tests() {
 fn cli_nix_tests() {
     trycmd::TestCases::new().case("tests/cmd/*_nix.toml");
 }
+
+#[test]
+#[cfg(feature = "nix-local")]
+fn cli_nix_local_tests() {
+    trycmd::TestCases::new().case("tests/cmd/*_nix_local.toml");
+}
